Change Log
==========

5.0.0
-----
- Initial release

5.0.1
-----
- Update travis password

5.0.3
-----
- Bug fix popular tip ListView
- New feature Download CSV

5.0.4
-----
- Bug fix: Only activate "YourTips" with published YourTip pages.
- Change: Verification message on tip submission form show word count now.
- Change: Download CSV on converted tip articles to only download relevant information.
